@@ -1,7 +1,7 @@
 // Debugging support for dynamic typing.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/object.h"
