@@ -1,20 +1,22 @@
 // ffloor2().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
 
-#include "cl_F.h"
-#include "cl_sfloat.h"
-#include "cl_ffloat.h"
-#include "cl_dfloat.h"
-#include "cl_lfloat.h"
-#include "cl_LF.h"
+#include "float/cl_F.h"
+#include "cln/sfloat.h"
+#include "cln/ffloat.h"
+#include "cln/dfloat.h"
+#include "cln/lfloat.h"
+#include "float/lfloat/cl_LF.h"
+
+namespace cln {
 
 const cl_F_fdiv_t ffloor2 (const cl_F& x)
 {
@@ -30,3 +32,5 @@ const cl_F_fdiv_t ffloor2 (const cl_F& x)
 	);
 #endif
 }
+
+}  // namespace cln
