@@ -1,7 +1,7 @@
 // minusp().
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/ffloat.h"
@@ -9,14 +9,13 @@
 
 // Implementation.
 
-#include "cl_FF.h"
+#include "float/ffloat/cl_FF.h"
 
 namespace cln {
 
-MAYBE_INLINE
-cl_boolean minusp (const cl_FF& x)
+CL_INLINE bool CL_INLINE_DECL(minusp) (const cl_FF& x)
 {
-	return (cl_boolean) ((sint32)cl_ffloat_value(x) < 0);
+	return (sint32)cl_ffloat_value(x) < 0;
 }
 
 }  // namespace cln
