@@ -3,7 +3,7 @@
 // It does not pull in all the complex function code.
 
 // General includes.
-#include "cl_sysdep.h"
+#include "base/cl_sysdep.h"
 
 // Specification.
 #include "cln/real_io.h"
@@ -12,7 +12,7 @@
 // Implementation.
 
 #include "cln/io.h"
-#include "cl_spushstring.h"
+#include "base/string/cl_spushstring.h"
 #include "cln/input.h"
 
 namespace cln {
@@ -26,17 +26,17 @@ public:
 	char* end_pointer (void) { return buffer+index; }
 };
 
-static cl_boolean number_char_p (char c)
+static bool number_char_p (char c)
 {
 	if ((c >= '0') && (c <= '9'))
-		return cl_true;
+		return true;
 	if (((c >= 'A') && (c <= 'Z')) || ((c >= 'a') && (c <= 'z')))
-		return cl_true;
+		return true;
 	switch (c) {
 		case '+': case '-': case '.': case '_': case '/':
-			return cl_true;
+			return true;
 		default:
-			return cl_false;
+			return false;
 	}
 }
 
@@ -48,8 +48,8 @@ const cl_R read_real (std::istream& stream, const cl_read_flags& flags)
 	var int c;
 	// Skip whitespace at the beginning.
 	loop {
-		c = freadchar(stream);
-		if (c == cl_EOF) goto eof;
+		c = stream.get();
+		if (stream.eof() || stream.fail()) goto eof;
 		if ((c == ' ') || (c == '\t') || (c == '\n'))
 			continue;
 		else
@@ -64,8 +64,8 @@ const cl_R read_real (std::istream& stream, const cl_read_flags& flags)
 		buffer.push(c);
 		// Read some digits, then a letter, then a token.
 		loop {
-			c = freadchar(stream);
-			if (c == cl_EOF) goto eof;
+			c = stream.get();
+			if (stream.eof() || stream.fail()) goto eof;
 			buffer.push(c);
 			if ((c >= '0') && (c <= '9'))
 				continue;
@@ -74,20 +74,19 @@ const cl_R read_real (std::istream& stream, const cl_read_flags& flags)
 		}
 		if (!(((c >= 'A') && (c <= 'Z')) || ((c >= 'a') && (c <= 'z'))))
 			goto syntax1;
-		buffer.push(c);
-		c = freadchar(stream);
-		if (c == cl_EOF) goto eof;
+		c = stream.get();
+		if (stream.eof() || stream.fail()) goto eof;
 	}
 	// Read a number token.
 	if (!number_char_p(c))
 		goto syntax1;
 	loop {
 		buffer.push(c);
-		c = freadchar(stream);
-		if (c == cl_EOF)
+		c = stream.get();
+		if (stream.eof() || stream.fail())
 			break;
 		if (!number_char_p(c)) {
-			funreadchar(stream,c);
+			stream.putback(c);
 			break;
 		}
 	}
@@ -99,10 +98,10 @@ const cl_R read_real (std::istream& stream, const cl_read_flags& flags)
 
 	// Handle syntax error.
 syntax1:	buffer.push(c);
-	read_number_bad_syntax(buffer.start_pointer(),buffer.end_pointer());
+	throw read_number_bad_syntax_exception(buffer.start_pointer(),buffer.end_pointer());
 
 	// Handle premature EOF.
-eof:	read_number_eof();
+eof:	throw read_number_eof_exception();
 }
 
 }  // namespace cln
